@@ -1,5 +1,5 @@
 #!/bin/bash
-#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,27 +16,14 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-# This script configure IP alias(es) inside RedHat like VE.
-#
-# Parameters are passed in environment variables.
-# Required parameters:
-#   IP_ADDR       - IP address(es) to add
-#                   (several addresses should be divided by space)
-# Optional parameters:
-#   VE_STATE      - state of VE; could be one of:
-#                     starting | stopping | running | stopped
-#   IPDELALL	  - delete all old interfaces
-#
+# Adds IP address(es) in a container running Red Hat-like distro.
 
 VENET_DEV=venet0
 VENET_DEV_CFG=ifcfg-$VENET_DEV
-
-
 IFCFG_DIR=/etc/sysconfig/network-scripts
 IFCFG=${IFCFG_DIR}/ifcfg-${VENET_DEV}
 NETFILE=/etc/sysconfig/network
 HOSTFILE=/etc/hosts
-ROUTE=${IFCFG_DIR}/route-${VENET_DEV}
 NETWORKRESTART=
 
 function fix_ifup()
@@ -66,16 +53,13 @@ IPADDR=127.0.0.1
 NETMASK=255.255.255.255
 BROADCAST=0.0.0.0" > $IFCFG || error "Can't write to file $IFCFG" $VZ_FS_NO_DISK_SPACE
 
-
-	remove_fake_old_route ${ROUTE}
-	if ! grep -q "${FAKEGATEWAYNET}/24 dev ${VENET_DEV}" ${ROUTE} 2>/dev/null; then
-		echo "${FAKEGATEWAYNET}/24 dev ${VENET_DEV} scope host
-default via ${FAKEGATEWAY}" >> ${ROUTE} || error "Can't create ${ROUTE}" ${VZ_FS_NO_DISK_SPACE}
-	fi
 	# Set /etc/sysconfig/network
 	put_param $NETFILE NETWORKING yes
-	put_param $NETFILE GATEWAY ${FAKEGATEWAY}
-
+	# Set default route to venet0
+	put_param $NETFILE GATEWAYDEV ${VENET_DEV}
+	# Remove old (obsoleted) fake route
+	del_param $NETFILE GATEWAY
+	[ -f "${IFCFG_DIR}/route-venet0" ] && rm -f ${IFCFG_DIR}/route-venet0
 	# setup ipv6
 	setup6_network
 
@@ -104,12 +88,13 @@ function create_config()
 {
 	local ip=$1
 	local ifnum=$2
+	local file=${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum}
 
 	echo "DEVICE=${VENET_DEV}:${ifnum}
 ONBOOT=yes
 IPADDR=${ip}
-NETMASK=255.255.255.255" > ${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum} ||
-	error "Unable to create interface config file" ${VZ_FS_NO_DISK_SPACE}
+NETMASK=255.255.255.255" > $file ||
+	error "Can't write to file $file" ${VZ_FS_NO_DISK_SPACE}
 }
 
 function add_ip6()
@@ -164,7 +149,7 @@ function backup_configs()
 	cd ${IFCFG_DIR} || return 1
 	if ls ${VENET_DEV_CFG}:* > /dev/null 2>&1; then
 		${CP} ${VENET_DEV_CFG}:* ${IFCFG_DIR}/bak/ ||
-			error "Unable to backup intrface config files" ${VZ_FS_NO_DISK_SPACE}
+			error "Unable to backup interface config files" ${VZ_FS_NO_DISK_SPACE}
 	fi
 }
 
@@ -182,10 +167,15 @@ function add_ip()
 	local new_ips
 	local if_restart=
 
-	# In case we are starting VE
+	# In case we are starting CT
 	if [ "x${VE_STATE}" = "xstarting" ]; then
 		# Remove all VENET config files
 		rm -f ${IFCFG} ${IFCFG}:* >/dev/null 2>&1
+		if [ -z "${IP_ADDR}" ]; then
+			# Just enable networking
+			put_param $NETFILE NETWORKING yes
+			return 0
+		fi
 	fi
 	if [ ! -f "${IFCFG}" ]; then
 		setup_network
@@ -221,6 +211,8 @@ function add_ip()
 		# synchronyze config files & interfaces
 		if [ "${NETWORKRESTART}" = "yes" ]; then
 			/etc/init.d/network restart
+		elif ! ifconfig ${VENET_DEV}|grep -q RUNNING 2>/dev/null; then
+			/etc/init.d/network restart
 		elif [ -n "${if_restart}" ]; then
 			ifup ${VENET_DEV}
 		else
