@@ -71,91 +71,117 @@ struct vzctl_ve_netdev {
 	char __user *dev_name;
 };
 
+struct vzctl_ve_pci_dev {
+	int domain;
+	unsigned int bus;
+	unsigned int slot;
+	unsigned int func;
+};
+
 struct vzctl_ve_meminfo {
 	envid_t veid;
 	unsigned long val;
 };
 
-/* these masks represent modules */
-#define VE_IP_IPTABLES_MOD		(1U<<0)
-#define VE_IP_FILTER_MOD		(1U<<1)
-#define VE_IP_MANGLE_MOD		(1U<<2)
-#define VE_IP_MATCH_LIMIT_MOD		(1U<<3)
-#define VE_IP_MATCH_MULTIPORT_MOD	(1U<<4)
-#define VE_IP_MATCH_TOS_MOD		(1U<<5)
-#define VE_IP_TARGET_TOS_MOD		(1U<<6)
-#define VE_IP_TARGET_REJECT_MOD		(1U<<7)
-#define VE_IP_TARGET_TCPMSS_MOD		(1U<<8)
-#define VE_IP_MATCH_TCPMSS_MOD		(1U<<9)
-#define VE_IP_MATCH_TTL_MOD		(1U<<10)
-#define VE_IP_TARGET_LOG_MOD		(1U<<11)
-#define VE_IP_MATCH_LENGTH_MOD		(1U<<12)
-#define VE_IP_CONNTRACK_MOD		(1U<<14)
-#define VE_IP_CONNTRACK_FTP_MOD		(1U<<15)
-#define VE_IP_CONNTRACK_IRC_MOD		(1U<<16)
-#define VE_IP_MATCH_CONNTRACK_MOD	(1U<<17)
-#define VE_IP_MATCH_STATE_MOD		(1U<<18)
-#define VE_IP_MATCH_HELPER_MOD		(1U<<19)
-#define VE_IP_NAT_MOD			(1U<<20)
-#define VE_IP_NAT_FTP_MOD		(1U<<21)
-#define VE_IP_NAT_IRC_MOD		(1U<<22)
-#define VE_IP_TARGET_REDIRECT_MOD	(1U<<23)
-#define VE_IP_MATCH_OWNER_MOD		(1U<<24)
-#define VE_IP_MATCH_MAC_MOD		(1U<<25)
-#define VE_IP_MATCH_RECENT_MOD		(1U<<26)
+struct vzctl_ve_configure {
+	unsigned int veid;
+	unsigned int key;
+#define VE_CONFIGURE_OS_RELEASE		2
+#define VE_CONFIGURE_ADD_PCI_DEVICE	3
+#define VE_CONFIGURE_DEL_PCI_DEVICE	4
+#define VE_CONFIGURE_CREATE_PROC_LINK	5
+	unsigned int val;
+	unsigned int size;
+	char data[0];
+};
 
-/* these masks represent modules with their dependences */
+/*
+ * These masks represent iptables modules.
+ *
+ * Strictly speaking, we use only a small subset
+ * of these bits nowdays, but we MUST RESERVE all of the
+ * bits that were ever used, for the sake of ABI compatibility.
+ *
+ * DON'T EVER DELETE/MODIFY THESE BITS
+ */
+#define VE_IPT(name, shift)	name = (1U << shift)
+enum ve_ipt_mods {
+	VE_IPT(VE_IP_IPTABLES_MOD,		0),
+	VE_IPT(VE_IP_FILTER_MOD,		1),
+	VE_IPT(VE_IP_MANGLE_MOD,		2),
+	VE_IPT(VE_IP_MATCH_LIMIT_MOD,		3),
+	VE_IPT(VE_IP_MATCH_MULTIPORT_MOD,	4),
+	VE_IPT(VE_IP_MATCH_TOS_MOD,		5),
+	VE_IPT(VE_IP_TARGET_TOS_MOD,		6),
+	VE_IPT(VE_IP_TARGET_REJECT_MOD,		7),
+	VE_IPT(VE_IP_TARGET_TCPMSS_MOD,		8),
+	VE_IPT(VE_IP_MATCH_TCPMSS_MOD,		9),
+	VE_IPT(VE_IP_MATCH_TTL_MOD,		10),
+	VE_IPT(VE_IP_TARGET_LOG_MOD,		11),
+	VE_IPT(VE_IP_MATCH_LENGTH_MOD,		12),
+	VE_IPT(VE_IP_CONNTRACK_MOD,		14),
+	VE_IPT(VE_IP_CONNTRACK_FTP_MOD,		15),
+	VE_IPT(VE_IP_CONNTRACK_IRC_MOD,		16),
+	VE_IPT(VE_IP_MATCH_CONNTRACK_MOD,	17),
+	VE_IPT(VE_IP_MATCH_STATE_MOD,		18),
+	VE_IPT(VE_IP_MATCH_HELPER_MOD,		19),
+	VE_IPT(VE_IP_NAT_MOD,			20),
+	VE_IPT(VE_IP_NAT_FTP_MOD,		21),
+	VE_IPT(VE_IP_NAT_IRC_MOD,		22),
+	VE_IPT(VE_IP_TARGET_REDIRECT_MOD,	23),
+	VE_IPT(VE_IP_MATCH_OWNER_MOD,		24),
+	VE_IPT(VE_IP_MATCH_MAC_MOD,		25),
+	VE_IPT(VE_IP_IPTABLES6_MOD,		26),
+	VE_IPT(VE_IP_FILTER6_MOD,		27),
+	VE_IPT(VE_IP_MANGLE6_MOD,		28),
+	VE_IPT(VE_IP_IPTABLE_NAT_MOD,		29),
+	VE_IPT(VE_NF_CONNTRACK_MOD,		30),
+	VE_IPT(VE_IP_MATCH_RECENT_MOD,		31),
+};
+#undef VE_IPT
+
+/* these masks represent modules with their dependencies */
 #define VE_IP_IPTABLES		(VE_IP_IPTABLES_MOD)
-#define VE_IP_FILTER		(VE_IP_FILTER_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_MANGLE		(VE_IP_MANGLE_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_LIMIT	(VE_IP_MATCH_LIMIT_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_MULTIPORT	(VE_IP_MATCH_MULTIPORT_MOD	\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_TOS		(VE_IP_MATCH_TOS_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_TARGET_TOS	(VE_IP_TARGET_TOS_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_TARGET_REJECT	(VE_IP_TARGET_REJECT_MOD	\
-					| VE_IP_IPTABLES)
-#define VE_IP_TARGET_TCPMSS	(VE_IP_TARGET_TCPMSS_MOD	\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_TCPMSS	(VE_IP_MATCH_TCPMSS_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_TTL		(VE_IP_MATCH_TTL_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_TARGET_LOG	(VE_IP_TARGET_LOG_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_LENGTH	(VE_IP_MATCH_LENGTH_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_CONNTRACK		(VE_IP_CONNTRACK_MOD		\
-					| VE_IP_IPTABLES)
-#define VE_IP_CONNTRACK_FTP	(VE_IP_CONNTRACK_FTP_MOD	\
-					| VE_IP_CONNTRACK)
-#define VE_IP_CONNTRACK_IRC	(VE_IP_CONNTRACK_IRC_MOD	\
-					| VE_IP_CONNTRACK)
-#define VE_IP_MATCH_CONNTRACK	(VE_IP_MATCH_CONNTRACK_MOD	\
-					| VE_IP_CONNTRACK)
-#define VE_IP_MATCH_STATE	(VE_IP_MATCH_STATE_MOD		\
-					| VE_IP_CONNTRACK)
-#define VE_IP_MATCH_HELPER	(VE_IP_MATCH_HELPER_MOD		\
-					| VE_IP_CONNTRACK)
-#define VE_IP_NAT		(VE_IP_NAT_MOD			\
-					| VE_IP_CONNTRACK)
-#define VE_IP_NAT_FTP		(VE_IP_NAT_FTP_MOD		\
-					| VE_IP_NAT | VE_IP_CONNTRACK_FTP)
-#define VE_IP_NAT_IRC		(VE_IP_NAT_IRC_MOD		\
-					| VE_IP_NAT | VE_IP_CONNTRACK_IRC)
-#define VE_IP_TARGET_REDIRECT	(VE_IP_TARGET_REDIRECT_MOD	\
-					| VE_IP_NAT)
-#define VE_IP_MATCH_MAC		(VE_IP_MATCH_MAC_MOD	\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_OWNER	(VE_IP_MATCH_OWNER_MOD	\
-					| VE_IP_IPTABLES)
-#define VE_IP_MATCH_RECENT	(VE_IP_MATCH_RECENT_MOD	\
-					| VE_IP_IPTABLES)
+#define VE_IP_FILTER		(VE_IP_FILTER_MOD | VE_IP_IPTABLES)
+#define VE_IP_MANGLE		(VE_IP_MANGLE_MOD | VE_IP_IPTABLES)
+#define VE_IP_IPTABLES6		(VE_IP_IPTABLES6_MOD)
+#define VE_IP_FILTER6		(VE_IP_FILTER6_MOD | VE_IP_IPTABLES6)
+#define VE_IP_MANGLE6		(VE_IP_MANGLE6_MOD | VE_IP_IPTABLES6)
+#define VE_NF_CONNTRACK		(VE_NF_CONNTRACK_MOD | VE_IP_IPTABLES)
+#define VE_IP_CONNTRACK		(VE_IP_CONNTRACK_MOD | VE_IP_IPTABLES)
+#define VE_IP_CONNTRACK_FTP	(VE_IP_CONNTRACK_FTP_MOD | VE_IP_CONNTRACK)
+#define VE_IP_CONNTRACK_IRC	(VE_IP_CONNTRACK_IRC_MOD | VE_IP_CONNTRACK)
+#define VE_IP_NAT		(VE_IP_NAT_MOD | VE_IP_CONNTRACK)
+#define VE_IP_NAT_FTP		(VE_IP_NAT_FTP_MOD | VE_IP_NAT | \
+				 VE_IP_CONNTRACK_FTP)
+#define VE_IP_NAT_IRC		(VE_IP_NAT_IRC_MOD | VE_IP_NAT | \
+				 VE_IP_CONNTRACK_IRC)
+#define VE_IP_IPTABLE_NAT	(VE_IP_IPTABLE_NAT_MOD | VE_IP_CONNTRACK)
+#define VE_IP_MATCH_LIMIT	(VE_IP_MATCH_LIMIT_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_MULTIPORT	(VE_IP_MATCH_MULTIPORT_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_TOS		(VE_IP_MATCH_TOS_MOD | VE_IP_IPTABLES)
+#define VE_IP_TARGET_TOS	(VE_IP_TARGET_TOS_MOD | VE_IP_IPTABLES)
+#define VE_IP_TARGET_REJECT	(VE_IP_TARGET_REJECT_MOD | VE_IP_IPTABLES)
+#define VE_IP_TARGET_TCPMSS	(VE_IP_TARGET_TCPMSS_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_TCPMSS	(VE_IP_MATCH_TCPMSS_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_TTL		(VE_IP_MATCH_TTL_MOD | VE_IP_IPTABLES)
+#define VE_IP_TARGET_LOG	(VE_IP_TARGET_LOG_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_LENGTH	(VE_IP_MATCH_LENGTH_MOD | VE_IP_IPTABLES)
+#define VE_IP_CONNTRACK		(VE_IP_CONNTRACK_MOD | VE_IP_IPTABLES)
+#define VE_IP_CONNTRACK_FTP	(VE_IP_CONNTRACK_FTP_MOD | VE_IP_CONNTRACK)
+#define VE_IP_CONNTRACK_IRC	(VE_IP_CONNTRACK_IRC_MOD | VE_IP_CONNTRACK)
+#define VE_IP_MATCH_CONNTRACK	(VE_IP_MATCH_CONNTRACK_MOD | VE_IP_CONNTRACK)
+#define VE_IP_MATCH_STATE	(VE_IP_MATCH_STATE_MOD | VE_IP_CONNTRACK)
+#define VE_IP_MATCH_HELPER	(VE_IP_MATCH_HELPER_MOD | VE_IP_CONNTRACK)
+#define VE_IP_NAT		(VE_IP_NAT_MOD | VE_IP_CONNTRACK)
+#define VE_IP_NAT_FTP		(VE_IP_NAT_FTP_MOD | VE_IP_NAT | \
+				 VE_IP_CONNTRACK_FTP)
+#define VE_IP_NAT_IRC		(VE_IP_NAT_IRC_MOD | VE_IP_NAT | \
+				 VE_IP_CONNTRACK_IRC)
+#define VE_IP_TARGET_REDIRECT	(VE_IP_TARGET_REDIRECT_MOD | VE_IP_NAT)
+#define VE_IP_MATCH_MAC		(VE_IP_MATCH_MAC_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_OWNER	(VE_IP_MATCH_OWNER_MOD | VE_IP_IPTABLES)
+#define VE_IP_MATCH_RECENT	(VE_IP_MATCH_RECENT_MOD | VE_IP_IPTABLES)
 
 /* safe iptables mask to be used by default */
 #define VE_IP_DEFAULT					\
@@ -265,6 +291,8 @@ struct vzctl_cpustatctl {
 					struct vzctl_ve_netdev)
 #define VZCTL_VE_MEMINFO	_IOW(VZCTLTYPE, 13,			\
 					struct vzctl_ve_meminfo)
+#define VZCTL_VE_CONFIGURE	_IOW(VZCTLTYPE, 15,			\
+					struct vzctl_ve_configure)
 
 #ifdef __KERNEL__
 #include <linux/compat.h>
