@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,11 @@
 #ifndef _UTIL_H_
 #define	_UTIL_H_
 
+#include <stdlib.h>
 #include "types.h"
+#include "res.h"
+#include "logger.h"
+
 #define BACKUP		0
 #define DESTR		1
 
@@ -37,7 +41,7 @@ char *arg2str(char **arg);
 void free_arg(char **arg);
 unsigned long min_ul(unsigned long val1, unsigned long val2);
 int yesno2id(const char *str);
-int get_netaddr(const char *ip_str, unsigned int *ip);
+int get_netaddr(const char *ip_str, void *ip);
 const char *get_netname(unsigned int *ip, int family);
 char *subst_VEID(envid_t veid, char *src);
 int get_pagesize();
@@ -50,8 +54,41 @@ unsigned long max_ul(unsigned long val1, unsigned long val2);
 void str_tolower(const char *from, char *to);
 char *get_file_name(char *str);
 const char *get_vps_state_str(int vps_state);
+int get_dump_file(unsigned veid, const char *dumpdir, char *buf, int size);
 int set_not_blk(int fd);
 void close_fds(int close_std, ...);
 int move_config(int veid, int action);
 void remove_names(envid_t veid);
+
+size_t vz_strlcat(char *dst, const char *src, size_t count);
+
+void get_osrelease(vps_res *res);
+
+#define logger_enomem(log_level, err, size, file, line)			\
+	logger(log_level, err, "%s:%i: Can't allocate %lu bytes",	\
+		file, line, (unsigned long)size)
+
+#define vz_malloc(size)						\
+	({							\
+		void *p = malloc(size);				\
+		if (!p)						\
+			logger_enomem(-1, ENOMEM, size,		\
+					__FILE__, __LINE__);	\
+		p;						\
+	})
+
+#define vz_strdup(str)						\
+	({							\
+		char *p = strdup(str);				\
+		if (!p)						\
+			logger_enomem(-1, ENOMEM, strlen(str),	\
+					__FILE__, __LINE__);	\
+		p;						\
+	})
+
+#define for_each_strtok(p, str, sep)				\
+	for (p = strtok(str, sep); p; p = strtok(NULL, sep))
+
+#define ARRAY_SIZE(x) (sizeof(x)/sizeof((x)[0]))
+
 #endif
