@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,8 +40,6 @@
 #define PARAM_NUMFILE		'n'
 #define PARAM_DCACHESIZE	'x'
 
-#define PARAM_PKGVER		11
-#define PARAM_PKGSET		12
 #define PARAM_OSTEMPLATE	13
 
 #define PARAM_CPUWEIGHT		14
@@ -112,8 +110,6 @@
 #define PARAM_DUMPDIR		338
 #define PARAM_SKIPARPDETECT	339
 #define PARAM_RESET_UB		340
-#define PARAM_VETH_ADD_CMD	341
-#define PARAM_VETH_DEL_CMD	342
 #define PARAM_VEID		343
 #define PARAM_NAME		344
 #define PARAM_APPLYCONFIG_MAP	345
@@ -134,6 +130,10 @@
 #define PARAM_NETIF_MAC_FILTER	360
 #define PARAM_NETIF_BRIDGE	361
 #define PARAM_DESCRIPTION	362
+#define PARAM_SWAPPAGES		363
+#define PARAM_BOOTORDER		364
+#define PARAM_PCI_ADD		365
+#define PARAM_PCI_DEL		366
 
 #define PARAM_LINE		"e:p:f:t:i:l:k:a:b:n:x:h"
 #endif
