@@ -74,8 +74,9 @@ struct Cquota {
 	unsigned long diskinodes[3];	// 0-usage 1-softlimit 2-hardlimit
 };
 
-struct Cla {
-	double la[3];
+struct Ccpustat {
+	float la[3];			// load average
+	float uptime;
 };
 
 struct Ccpu {
@@ -97,7 +98,7 @@ struct Cveinfo {
 	char *ve_root;
 	struct Cubc *ubc;
 	struct Cquota *quota;
-	struct Cla *la;
+	struct Ccpustat *cpustat;
 	struct Ccpu *cpu;
 	struct Cio io;
 	int status;
@@ -111,7 +112,7 @@ struct Cveinfo {
 #define RES_UBC		2
 #define RES_QUOTA	3
 #define RES_IP		4
-#define RES_LA		5
+#define RES_CPUSTAT	5
 #define RES_CPU		6
 
 struct Cfield {
